import type { BpmnElementKind, BpmnSemantic, ElementsRegistry } from 'bpmn-visualization';
import { ShapeBpmnElementKind, ShapeUtil as BaseShapeUtil } from 'bpmn-visualization';
/**
 * Options to deduplicate elements when several names match.
 */
export type DeduplicateNamesOptions = {
    /** If not set, use all `BpmnElementKind` values. */
    kinds?: BpmnElementKind[];
    /** Apply custom function to filter duplicates. */
    filter?: (bpmnSemantic: BpmnSemantic) => boolean;
};
/**
 * Provides workarounds for {@link https://github.com/process-analytics/bpmn-visualization-js/issues/2453}.
 */
export declare class BpmnElementsSearcher {
    private readonly elementsRegistry;
    constructor(elementsRegistry: ElementsRegistry);
    /**
     * Find the ID of the first element that matches the provided name.
     * @param name the name of the element to retrieve.
     */
    getElementIdByName(name: string): string | undefined;
    /**
     * Find the element that matches the provided name.
     *
     * Use the `deduplicateOptions` parameter to modify the default behavior of deduplication processing.
     *
     * The deduplication process is done in this order:
     * - look for elements matching the provided kinds. If not specified, use all `BpmnElementKind` values.
     * - apply the deduplication filter if provided, otherwise take the first element corresponding to the name provided.
     *
     * @param name the name of the element to retrieve.
     * @param deduplicateOptions if not defined, or if the object doesn't define any properties, duplicates are filtered out by selecting the first element corresponding to the name provided.
     */
    getElementByName(name: string, deduplicateOptions?: DeduplicateNamesOptions): BpmnSemantic | undefined;
    /**
     * Returns all elements matching the names passed in parameter.
     *
     * The number of elements returned may differ from the number of names passed in parameter:
     * - if there are no elements matching the names
     * - if one of the names does not correspond to any elements
     * - if a name corresponds to several elements (duplicates)
     *
     * @param names the names of the elements to retrieve.
     */
    getElementsByNames(names: string[]): BpmnSemantic[];
}
export declare class BpmnElementsIdentifier {
    private readonly elementsRegistry;
    constructor(elementsRegistry: ElementsRegistry);
    isActivity(elementId: string): boolean;
    isBpmnArtifact(elementId: string): boolean;
    isGateway(elementId: string): boolean;
    isEvent(elementId: string): boolean;
    private isInCategory;
}
export declare class ShapeUtil extends BaseShapeUtil {
    static isBpmnArtifact(kind: ShapeBpmnElementKind | string): boolean;
}
