/*
Copyright 2024 Bonitasoft S.A.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
/**
 * Provide CSS classes operations on BPMN elements.
 *
 * This plugin is a wrapper that delegates the actual CSS classes operations to {@link BpmnElementsRegistry}.
 *
 * @since 0.7.0
 */
export class CssClassesPlugin {
    constructor(bpmnVisualization) {
        Object.defineProperty(this, "cssRegistry", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.cssRegistry = bpmnVisualization.bpmnElementsRegistry;
    }
    getPluginId() {
        return 'css';
    }
    addCssClasses(bpmnElementIds, classNames) {
        this.cssRegistry.addCssClasses(bpmnElementIds, classNames);
    }
    removeCssClasses(bpmnElementIds, classNames) {
        this.cssRegistry.removeCssClasses(bpmnElementIds, classNames);
    }
    removeAllCssClasses(bpmnElementIds) {
        this.cssRegistry.removeAllCssClasses(bpmnElementIds);
    }
    toggleCssClasses(bpmnElementIds, classNames) {
        this.cssRegistry.toggleCssClasses(bpmnElementIds, classNames);
    }
}
